package com.ruoyi.web.controller.dz;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dz.domain.DzPaymentOrders;
import com.ruoyi.dz.service.IDzPaymentOrdersService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单Controller
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
@RestController
@RequestMapping("/dz/orders")
public class DzPaymentOrdersController extends BaseController
{
    @Autowired
    private IDzPaymentOrdersService dzPaymentOrdersService;

    /**
     * 查询订单列表
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:list')")
    @GetMapping("/list")
    public TableDataInfo list(DzPaymentOrders dzPaymentOrders)
    {
        startPage();
        List<DzPaymentOrders> list = dzPaymentOrdersService.selectDzPaymentOrdersList(dzPaymentOrders);
        return getDataTable(list);
    }

    /**
     * 导出订单列表
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:export')")
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DzPaymentOrders dzPaymentOrders)
    {
        List<DzPaymentOrders> list = dzPaymentOrdersService.selectDzPaymentOrdersList(dzPaymentOrders);
        ExcelUtil<DzPaymentOrders> util = new ExcelUtil<DzPaymentOrders>(DzPaymentOrders.class);
        util.exportExcel(response, list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dzPaymentOrdersService.selectDzPaymentOrdersById(id));
    }

    /**
     * 新增订单
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:add')")
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DzPaymentOrders dzPaymentOrders)
    {
        return toAjax(dzPaymentOrdersService.insertDzPaymentOrders(dzPaymentOrders));
    }

    /**
     * 修改订单
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:edit')")
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DzPaymentOrders dzPaymentOrders)
    {
        return toAjax(dzPaymentOrdersService.updateDzPaymentOrders(dzPaymentOrders));
    }

    /**
     * 删除订单
     */
    @PreAuthorize("@ss.hasPermi('dz:orders:remove')")
    @Log(title = "订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dzPaymentOrdersService.deleteDzPaymentOrdersByIds(ids));
    }
}
